@@ -2,24 +2,29 @@ package Weed;
 use strict;
 use warnings;
 
-our $VERSION = '0.0014';
+our $VERSION = '0.0016';
 
 use base 'UNIVERSAL';
 
 sub import {
-	#my ( $class ) = @_;
+	shift;
+	my ($description) = @_;
 
 	my $package = caller;
 
 	return if $package eq "main";
 
 	unshift @{ Weed::Universal::ARRAY( $package, 'ISA' ) }, 'X3DObject';
+	${ Weed::Universal::SCALAR( $package, 'DESCRIPTION' ) } = $description;
 
 	#printf "import weed   *** %s\n", $package;
 }
 
 use Weed::Environment;
 
+1;
+__END__
+
 =head1 NAME
 
 Weed - ist ein englisches Wort fr Unkraut
@@ -96,6 +101,3 @@ Das ist freie Software; du kannsts sie weiter verteilen und/oder verndern
 nach den gleichen Bedingungen wie L<Perl|perl> selbst.
 
 =cut
-
-1;
-__END__
