@@ -2,11 +2,9 @@ package Weed::Component::Core;
 use strict;
 use warnings;
 
-our $VERSION = '0.0011';
+our $VERSION = '0.0013';
 
-use Weed;
-
-our $DESCRIPTION = '
+use Weed '
 X3DComponentCore : X3DComponent {
   SFNode [in,out] metadata NULL [X3DMetadataObject]
 }
