@@ -2,11 +2,9 @@ package Weed::Component::Core::ChildNode;
 use strict;
 use warnings;
 
-our $VERSION = '0.0011';
+our $VERSION = '0.0013';
 
-use Weed;
-
-our $DESCRIPTION = '
+use Weed '
 X3DChildNode : X3DNode { 
 	SFNode [in,out] metadata NULL [X3DMetadataObject]
 }
