@@ -2,11 +2,9 @@ package Weed::Field;
 use strict;
 use warnings;
 
-our $VERSION = '0.0011';
+our $VERSION = '0.0013';
 
-use Weed;
-
-our $DESCRIPTION = 'X3DField { }';
+use Weed 'X3DField { }';
 
 use constant DefaultDefinition => new X3DFieldDefinition( "", "in", "out", undef, undef, undef );
 
