@@ -2,11 +2,9 @@ package Weed::Generator;
 use strict;
 use warnings;
 
-our $VERSION = '0.0011';
+our $VERSION = '0.0013';
 
-use Weed;
-
-our $DESCRIPTION = 'X3DGenerator {}';
+use Weed 'X3DGenerator {}';
 
 sub new {
 	my ( $self, $name ) = @_;
